@@ -239,26 +239,29 @@ fn clean_cache(max_age: u128) -> MainResult<()> {
     info!("cutoff:     {:>20?} ms", cutoff);
 
     let cache_dir = platform::generated_projects_cache_path();
-    for child in fs::read_dir(cache_dir)? {
-        let child = child?;
-        let path = child.path();
-        if path.is_file() {
-            continue;
-        }
 
-        info!("checking: {:?}", path);
+    if cache_dir.exists() {
+        for child in fs::read_dir(cache_dir)? {
+            let child = child?;
+            let path = child.path();
+            if path.is_file() {
+                continue;
+            }
 
-        let remove_dir = || {
-            let meta_mtime = platform::dir_last_modified(&child);
-            info!("meta_mtime: {:>20?} ms", meta_mtime);
+            info!("checking: {:?}", path);
 
-            meta_mtime <= cutoff
-        };
+            let remove_dir = || {
+                let meta_mtime = platform::dir_last_modified(&child);
+                info!("meta_mtime: {:>20?} ms", meta_mtime);
 
-        if remove_dir() {
-            info!("removing {:?}", path);
-            if let Err(err) = fs::remove_dir_all(&path) {
-                error!("failed to remove {:?} from cache: {}", path, err);
+                meta_mtime <= cutoff
+            };
+
+            if remove_dir() {
+                info!("removing {:?}", path);
+                if let Err(err) = fs::remove_dir_all(&path) {
+                    error!("failed to remove {:?} from cache: {}", path, err);
+                }
             }
         }
     }
@@ -477,6 +480,8 @@ impl InputAction {
             } else {
                 return Err(MainError::OtherOwned("Could not execute cargo".to_string()));
             }
+        } else {
+            cmd.args(script_args.iter());
         }
 
         Ok(cmd)
