@@ -89,6 +89,29 @@ fn test_script_short_without_main() {
 fn test_script_test() {
     let out = rust_script!("--test", "tests/data/script-test.rs").unwrap();
     assert!(out.success());
+    assert!(out.stdout.contains("running 1 test"));
+}
+
+#[test]
+fn test_script_test_extra_args_for_cargo() {
+    let out = rust_script!("--test", "tests/data/script-test-extra-args.rs", "--help",).unwrap();
+    assert!(out.success());
+    assert!(out
+        .stdout
+        .contains("Execute all unit and integration tests"));
+}
+
+#[test]
+fn test_script_test_extra_args_for_test() {
+    let out = rust_script!(
+        "--test",
+        "tests/data/script-test-extra-args.rs",
+        "--",
+        "--nocapture"
+    )
+    .unwrap();
+    assert!(out.success());
+    assert!(out.stdout.contains("Hello, world!"));
 }
 
 #[test]
